Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(498)

Unified Diff: util/file/string_file.h

Issue 936153002: Add FileReaderInterface. Move StringFileWriter to StringFile and (Closed) Base URL: https://chromium.googlesource.com/crashpad/crashpad@master
Patch Set: Remove unused #include Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « util/file/file_writer.cc ('k') | util/file/string_file.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: util/file/string_file.h
diff --git a/util/file/string_file_writer.h b/util/file/string_file.h
similarity index 66%
rename from util/file/string_file_writer.h
rename to util/file/string_file.h
index bdfb5e55902a1e31bf42edf4f5b329f57bbd9eea..b6876b328f20c0362d27f0fd8c2e500487dcc1f0 100644
--- a/util/file/string_file_writer.h
+++ b/util/file/string_file.h
@@ -12,8 +12,8 @@
// See the License for the specific language governing permissions and
// limitations under the License.
-#ifndef CRASHPAD_UTIL_FILE_STRING_FILE_WRITER_H_
-#define CRASHPAD_UTIL_FILE_STRING_FILE_WRITER_H_
+#ifndef CRASHPAD_UTIL_FILE_STRING_FILE_H_
+#define CRASHPAD_UTIL_FILE_STRING_FILE_H_
#include <sys/types.h>
@@ -21,32 +21,42 @@
#include "base/basictypes.h"
#include "base/numerics/safe_math.h"
+#include "util/file/file_reader.h"
#include "util/file/file_writer.h"
namespace crashpad {
//! \brief A file writer backed by a virtual file, as opposed to a file on disk
//! or other operating system file descriptor-based file.
//!
//! The virtual file is a buffer in memory. This class is convenient for use
-//! with other code that normally expects to write files, when it is impractical
-//! or inconvenient to write a file. It is expected that tests, in particular,
-//! will benefit from using this class.
-class StringFileWriter : public FileWriterInterface {
+//! with other code that normally expects to read or write files, when it is
+//! impractical or inconvenient to read or write a file. It is expected that
+//! tests, in particular, will benefit from using this class.
+class StringFile : public FileReaderInterface, public FileWriterInterface {
public:
- StringFileWriter();
- ~StringFileWriter();
+ StringFile();
+ ~StringFile();
//! \brief Returns a string containing the virtual file’s contents.
const std::string& string() const { return string_; }
+ //! \brief Sets the virtual file’s contents to \a string, and resets its file
+ //! position to `0`.
+ void SetString(const std::string& string);
+
//! \brief Resets the virtual file’s contents to be empty, and resets its file
//! position to `0`.
void Reset();
+ // FileReaderInterface:
+ ssize_t Read(void* data, size_t size) override;
+
// FileWriterInterface:
bool Write(const void* data, size_t size) override;
bool WriteIoVec(std::vector<WritableIoVec>* iovecs) override;
+
+ // FileSeekerInterface:
FileOffset Seek(FileOffset offset, int whence) override;
private:
@@ -62,9 +72,9 @@ class StringFileWriter : public FileWriterInterface {
//! between these distinct types.
base::CheckedNumeric<size_t> offset_;
- DISALLOW_COPY_AND_ASSIGN(StringFileWriter);
+ DISALLOW_COPY_AND_ASSIGN(StringFile);
};
} // namespace crashpad
-#endif // CRASHPAD_UTIL_FILE_STRING_FILE_WRITER_H_
+#endif // CRASHPAD_UTIL_FILE_STRING_FILE_H_
« no previous file with comments | « util/file/file_writer.cc ('k') | util/file/string_file.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -21,32 +21,42 @@
#include "util/file/file_writer.h"
namespace crashpad {
-//! \brief A file writer backed by a virtual file, as opposed to a file on disk
-//! or other operating system file descriptor-based file.
+//! \brief A file reader and writer backed by a virtual file, as opposed to a
+//! file on disk or other operating system file descriptor-based file.
//!
//! The virtual file is a buffer in memory. This class is convenient for use
This is Rietveld 408576698